@@ -68,12 +68,14 @@ func main() {
 			BinName:  args[1],
 			Args:     args[1:],
 			ExtraEnv: getCliExtraEnv(),
+			Logger:   terminal.Logger,
 		}
 		os.Exit(e.Execute(true))
 	}
 	// called via "symfony console"?
 	if len(args) >= 2 && args[1] == "console" {
 		if executor, err := php.SymonyConsoleExecutor(args[2:]); err == nil {
+			executor.Logger = terminal.Logger
 			executor.ExtraEnv = getCliExtraEnv()
 			os.Exit(executor.Execute(false))
 		}
